%% Funzione di snervamento

[F,~,~] = Phi_array(s);

function [F,Phis,wv] = Phi_array(s)

    sx = s(1);
    sy = s(2);
    txy = s(3);
    % Parametri materiali
    % CDP
    sigma_c = 6.8E6; % resistenza a compressione
    sigma_t = 1.5E6; % resistenza a trazione
    alfa = 0.1212;
    K = 2/3;
    
    % Giunti di malta
    mi = 0.7536; % coefficiente d'attrito
    c_tau = 350000; % coesione tangenziale
    c_n = 250000; % coesione normale
    % Texture
    h_b = 0.052; % altezza blocco
    l_b = 0.21; % larghezza blocco
    beta_cell = 0.5; % rapporto interfaccia/blocco sulla cella
    f = 0.5; % bonding ratio
    
    % CDP
    gamma = (3*(1-K))/(2*K-1);
    beta = ((sigma_c/sigma_t)*(1-alfa) - (1+alfa));
    s1_eig = (sx + sy)/2 + sqrt(((sx-sy)/2)^2+txy^2);
    s2_eig = (sx + sy)/2 - sqrt(((sx-sy)/2)^2+txy^2);
    s3_eig = 0;
    s_vec = [s1_eig; s2_eig; s3_eig(s);];
    smax = max(max(s_vec), 0);
    p = -1/3*(sx+sy);
    S = diag(s_vec) + p*eye(3);
    q = sqrt(3/2*sum(sum(S.*S)));
    Phi_CDP = ((1/(1-alfa))*(q - 3*alfa*p + beta*max(smax,0) - gamma*max(-smax,0))-sigma_c);
    
    % Horizontal mechanism
    Phi_h_h = abs(txy) + sy*mi - c_tau;
    Phi_h_v = sy - c_n;
    
    % Diagonal mechanism
    Phi_d_h = (abs(txy) + (sy + (2*h_b/l_b)*(abs(txy)))*mi  - c_tau + (sx - c_n)*2*h_b/l_b);
    Phi_d_v = (abs(txy) + (sx + (l_b/(2*h_b))*(abs(txy)))*mi - c_tau + (l_b/(2*h_b))*(sy - c_n));
    
    % Vertical mechanism
    Phi_v = sx - c_n + (sy*mi - c_tau)*f*l_b/(2*h_b);
    
    % Mixed mechanism
    sx_star = (sx<c_n*(1-beta_cell))*sx + (sx>=c_n*(1-beta_cell))*max(((1/beta_cell)*(sx - c_n*(1-beta_cell))),sx);
    tau_star = max([(abs(txy)+sx*mi*(1-beta_cell) - c_tau*(1-beta_cell))/beta_cell,txy]);
    s1_eig_star = (sx_star + sy)/2 + sqrt(((sx_star-sy)/2)^2+tau_star^2);
    s2_eig_star = (sx_star + sy)/2 - sqrt(((sx_star-sy)/2)^2+tau_star^2);
    s3_eig_star = 0;
    s_vec_star = [s1_eig_star; s2_eig_star; s3_eig_star;];
    smax_star = max(max(s_vec_star), 0);
    p_star = -1/3*(sx_star + sy);
    S_star = diag(s_vec_star) + p_star*eye(3);
    q_star = sqrt(3/2*sum(sum(S_star.*S_star)));
    Phi_mixed = ((1/(1-alfa))*(q_star - 3*alfa*p_star + beta*max(smax_star,0) - gamma*max(-smax_star,0))-sigma_c);
    
    Phis = [Phi_CDP,Phi_h_h,Phi_h_v,Phi_d_h,Phi_d_v,Phi_v,Phi_mixed];
    theta = 50/(max(abs(stress_state))+1e-3);

    wv = exp(theta*Phis)/sum(exp(theta*Phis)); % array di pesi, 1xNs
    % LSE
    F = log(sum(exp(theta*Phis)))/theta;

end

